aboutsummaryrefslogtreecommitdiff
path: root/bdep/bdep.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'bdep/bdep.cxx')
-rw-r--r--bdep/bdep.cxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/bdep/bdep.cxx b/bdep/bdep.cxx
index ca6ff64..77dcd71 100644
--- a/bdep/bdep.cxx
+++ b/bdep/bdep.cxx
@@ -16,7 +16,7 @@
#include <bdep/diagnostics.hxx>
#include <bdep/bdep-options.hxx>
-#include <bdep/config-options.hxx>
+#include <bdep/project-options.hxx>
// Commands.
//
@@ -33,11 +33,11 @@ using namespace bdep;
// Once this is done, use the "final" values of the common options to do
// global initializations (verbosity level, etc).
//
// If O is-a configuration_options, then also handle the @<cfg-name> arguments
// and place them into configuration_options::config_name.
//
static inline bool
-cfg_name (configuration_options* o, const char* a)
+cfg_name (project_options* o, const char* a)
{
string n (a);
@@ -33,11 +33,11 @@ using namespace bdep;
// global initializations (verbosity level, etc).
//
-// If O is-a configuration_options, then also handle the @<cfg-name> arguments
-// and place them into configuration_options::config_name.
+// If O is-a project_options, then also handle the @<cfg-name> arguments and
+// place them into project_options::config_name.
//
static inline bool